@@ -138,6 +138,33 @@ def first_non_none(*args):
     return next(filter(lambda x: x is not None, args), None)  # pylint: disable=filter-builtin-not-iterating
 
 
+def parse_positive_integer(s):
+    """Parse a positive integer from a string representation.
+
+    Args:
+        s (Optional[Union[str, int]]): string representation of a positive integer, or just an integer
+
+    Returns:
+        Optional[int]: the parsed integer result, return :data:`None` if input is :data:`None` or empty string
+
+    Raises:
+        TypeError: if ``s`` is not :obj:`str` or :obj:`int`
+        ValueError: if ``s`` is an invalid positive integer value
+
+    """
+    if s is None or s == '':  # pylint: disable=compare-to-empty-string
+        return None
+    if not isinstance(s, (str, int)):
+        raise TypeError('expect str or int, got {!r}'.format(s))
+    try:
+        value = int(s)
+    except ValueError:
+        raise ValueError('expect an integer value, got {!r}'.format(s)) from None
+    if value <= 0:
+        raise ValueError('expect integer value to be positive, got {!r}'.format(value))
+    return value
+
+
 #: Dict[str, bool]: A mapping from string representation to boolean states.
 #: The values are used for :func:`parse_boolean_state`.
 _boolean_state_lookup = {
@@ -227,27 +254,35 @@ def parse_linesep(s):
 
 
 def parse_indentation(s):
-    """Parse indentation from a string representation.
+    r"""Parse indentation from a string representation.
 
-    * If a string of positive integer ``n`` is specified, then indentation is ``n`` spaces.
+    * If an integer or a string of positive integer ``n`` is specified, then indentation is ``n`` spaces.
     * If ``'t'`` or ``'tab'`` is specified, then indentation is tab.
+    * If ``'\t'``  (the tab character itself) or a string consisting only of the space character (U+0020) is
+        specified, it is returned directly.
 
     Value matching is **case insensitive**.
 
     Args:
-        s (Optional[str]): string representation of indentation
+        s (Optional[Union[str, int]]): string representation of indentation
 
     Returns:
         Optional[str]: the parsed indentation result, return :data:`None` if input is :data:`None` or empty string
 
     Raises:
+        TypeError: if ``s`` is not :obj:`str` or :obj:`int`
         ValueError: if ``s`` is an invalid indentation value
 
     """
-    if not s:
+    if s is None or s == '':  # pylint: disable=compare-to-empty-string
         return None
-    if s.lower() in {'t', 'tab'}:
-        return '\t'
+    if not isinstance(s, (str, int)):
+        raise TypeError('expect str or int, got {!r}'.format(s))
+    if isinstance(s, str):
+        if s.lower() in {'t', 'tab', '\t'}:
+            return '\t'
+        if s == ' ' * len(s):
+            return s
     try:
         n = int(s)
         if n <= 0:
@@ -729,7 +764,7 @@ class Config(collections.abc.MutableMapping):
         return '%s(%s)' % (type_name, ', '.join(arg_strings))
 
 
-__all__ = ['get_parso_grammar_versions', 'first_truthy', 'first_non_none',
+__all__ = ['get_parso_grammar_versions', 'first_truthy', 'first_non_none', 'parse_positive_integer',
            'parse_boolean_state', 'parse_linesep', 'parse_indentation', 'BPCSyntaxError', 'UUID4Generator',
            'detect_files', 'archive_files', 'recover_files', 'detect_encoding', 'detect_linesep',
            'detect_indentation', 'parso_parse', 'map_tasks', 'TaskLock', 'Config']
